@@ -2,7 +2,7 @@
 #
 #   Finance::SE::PPM.pm - A module for fetching account information from the swedish PPM
 #
-#   $Id: PPM.pm,v 1.2 2004/11/30 08:06:25 erwan Exp $
+#   $Id: PPM.pm,v 1.3 2008-08-26 10:30:35 erwan Exp $
 #  
 #   Erwan Lemonnier - 2004
 #
@@ -12,6 +12,8 @@
 
 package Finance::SE::PPM;
 
+die "Do NOT use this module";
+
 # Note: Crypt::SSLeay requires:
 #
 # MIME-Base64-3.00.tar.gz 
@@ -50,7 +52,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 #---------------------------------------------------------------------
 #
@@ -552,18 +554,13 @@ Finance::SE::PPM - Retrieve a person's account status from the Swedish PPM
 
 =head1 SYNOPSIS
 
-    use Data::Dumper;
-    use Finance::SE::PPM;
-
-    my $ppm = new Finance::SE::PPM(personnummer => '197805021025',
-                                   pincode => '45892');
-
-    $ppm->setProxy('proxy:8080');  # if required
-    $ppm->fetchAccountStatus();
-    print Dumper($ppm->getAccountFunds());
-
 =head1 DESCRIPTION
 
+DO NOT USE THIS MODULE!
+IT DOES NOT WORK AND WILL NOT BE FIXED!
+
+---------------
+
 Finance::SE::PPM provides a simple interface to retrieve the state of a
 pension saver's account in the Swedish PPM system.
 
